aboutsummaryrefslogtreecommitdiff
path: root/src/patch/patch.hh
diff options
context:
space:
mode:
Diffstat (limited to 'src/patch/patch.hh')
-rw-r--r--src/patch/patch.hh8
1 files changed, 4 insertions, 4 deletions
diff --git a/src/patch/patch.hh b/src/patch/patch.hh
index 56300a9..621a29f 100644
--- a/src/patch/patch.hh
+++ b/src/patch/patch.hh
@@ -408,17 +408,17 @@ public:
// or error_exit() if it's not actually a neighboring patch
// ... computation done using only (rho,sigma) coordinate sets
// and min/max dang bounds ==> ok to use in setting up ghost zones
// ... N_overlap_points = number of grid points (grid spacings
// in the perpendicular direction) these patches' nominal grids
// overlap,
// ... if this is nonzero, then these patches must have
// the *same* grid spacing in the perpendicular direction
// ... e.g. delta_dang = 5, this patch max_dang = 50,
- // other patch min_dang = 40 ==> N_overlap_points = 3
+ // other patch min_dang = 40 ==> patch_overlap_width = 3
// p p p p p
// q q q q q
const patch_edge& edge_adjacent_to_patch(const patch& q,
- int N_overlap_points = 0)
+ int patch_overlap_width = 0)
const;
@@ -502,7 +502,7 @@ public:
// the setup process
void create_interpatch_ghost_zone
(const patch_edge& my_edge, const patch_edge& other_edge,
- int N_overlap_points);
+ int patch_overlap_width);
// assert() that all ghost zones
// are fully setup
@@ -408,17 +408,17 @@ public:
// ... computation done using only (rho,sigma) coordinate sets
// and min/max dang bounds ==> ok to use in setting up ghost zones
- // ... N_overlap_points = number of grid points (grid spacings
+ // ... patch_overlap_width = number of grid points (grid spacings
// in the perpendicular direction) these patches' nominal grids
// overlap,